module.exports = defineTest({
	description: 'handles accessing the value of a getter before it has been bound'
});
